@@ -2,11 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Stock Management',
+    'name_bg_BG': 'Управление на наличности',
     'name_de_DE': 'Lagerverwaltung',
     'name_es_CO': 'Inventarios',
     'name_es_ES': 'Gestión de existencias',
     'name_fr_FR': 'Gestion des stocks',
-    'version': '1.8.7',
+    'name_ru_RU': 'Управление складами',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -21,6 +23,18 @@ And with reports:
     - Picking List
     - Restocking List (on Supplier Shipment and Customer Return Shipment)
     - Products by Locations
+''',
+    'description_bg_BG': '''Управление на наличности и контрол на инвентаризация с:
+    - Задаване на местонахождения
+    - Движения на наличност
+    - Пратки за клиент, от доставчик, вътрешни пратки. Върнати пратки от клиент и за доставчик.
+    - Инвентаризация на наличност
+
+Със следните справки:
+    - Бележка за доставка
+    - Опаковъчен лист
+    - Преизчисляване на инвентарен опис (при пратка на доставчик и пратка върната от клиент)
+    - Продукти по местонахождение
 ''',
     'description_de_DE': '''Lagerverwaltung und Bestandskontrolle mit:
     - Definition von Lagerorten
@@ -67,6 +81,18 @@ Et les rapports:
     - Liste de prélèvement
     - Liste de restockage (sur l'expédition fournisseur et le retour d'expédition client)
     - Quantités de produit par location
+''',
+    'description_ru_RU': '''Управление складами и запасами:
+    - Определение мест хранения
+    - Складские перемещения
+    - Приход, отгрузки, внутренние перемещения. Возвраты поставщикам и от заказчиков.
+    - Складской учет
+
+И с отчетами:
+    - Доставка
+    - Упаковка
+    - Инвентаризация (на приход от поставщиков и возвраты клиентов)
+    - ТМЦ по местам хранения
 ''',
     'depends': [
         'ir',
@@ -85,11 +111,14 @@ Et les rapports:
         'inventory.xml',
         'party.xml',
         'configuration.xml',
+        'period.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'ru_RU.csv',
     ],
 }
